'use client'
import React, { useEffect, useState } from 'react'
import { MapContainer, TileLayer, Marker, Popup, useMap } from 'react-leaflet';
import L from 'leaflet';

import 'leaflet/dist/leaflet.css';
import useShowToast from '@/app/hooks/useShowToast';
import { createLocationRequest } from '@/app/lib/attendance/action';
import { getAttendance } from './attendance';
import { setStorage } from '@/utils/navigation';

// Create a custom icon
const customIcon = new L.Icon({
    iconUrl: 'https://unpkg.com/leaflet@1.9.3/dist/images/marker-icon-2x.png',
    iconSize: [25, 41], // Adjust the size of the icon
    iconAnchor: [16, 32], // Anchor the icon (middle-bottom)
    popupAnchor: [0, -32], // Position the popup above the icon
});

const Location2 = () => {
    const showToast = useShowToast();
    const [currentLocation, setCurrentLocation] = useState(null);

    const handleSendLocation = async ({ latitude, longitude }: { latitude: number, longitude: number }) => {
        try {
            const form = {
                latitude: latitude,
                longitude: longitude,
                status: "active"
            }
            const response = await createLocationRequest(form);
            // showToast("Created!", response.message, "success");

        } catch (error: any) {
            showToast("Failed to create", error.message, "error");
        }
    };

    // Get current location
    useEffect(() => {
        let watchId: number;

        if (navigator.geolocation) {
            // Watch for location changes
            watchId = navigator.geolocation.watchPosition(
                (position) => {
                    setCurrentLocation([position?.coords?.latitude, position?.coords?.longitude]);
                    setStorage('lat-lng', { latitude: position?.coords?.latitude, longitude: position?.coords?.longitude })
                    const attendance = getAttendance()
                    attendance && handleSendLocation({ latitude: position?.coords?.latitude, longitude: position?.coords?.longitude })
                },
                (error) => {
                    console.error('Error watching location:', error);
                },
                {
                    enableHighAccuracy: true, // Use GPS for better accuracy
                    maximumAge: 0,           // Don't use cached positions
                    timeout: 180000           // Timeout after - seconds
                }
            );
        } else {
            alert('Geolocation is not supported by this browser.');
        }

        // Cleanup the watcher on component unmount
        return () => {
            if (watchId) navigator.geolocation.clearWatch(watchId);
        };
    }, []);
    return (
        <>
            {currentLocation && (
                <MapContainer center={currentLocation || [51.505, -0.09]} zoom={14} style={{ height: '500px', width: '100%' }}>
                    <TileLayer
                        attribution='&copy; <a href="https://www.openstreetmap.org/copyright">OpenStreetMap</a> contributors'
                        url="https://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png"
                    />
                    {currentLocation && (
                        <Marker position={currentLocation} icon={customIcon}>
                            <Popup>You are here!</Popup>
                        </Marker>
                    )}
                    <UpdateMapView position={currentLocation} />
                </MapContainer>
            )}
        </>
    )
}

export default Location2


const UpdateMapView = ({ position }) => {
    const map = useMap();
    useEffect(() => {
        if (position) {
            map.setView(position, map.getZoom()); // Keep the same zoom level
        }
    }, [position, map]);
    return null;
};